@@ -24,6 +24,7 @@ $(document).ready(function() {
     }).trigger('change');
 	
 	prettyPrint();
+	sh_highlightDocument();
 	$('#content').keyup(function() {
 		fetchPreview.only_every(on_change_refresh_rate);
 		oneshot_preview(fetchPreview, oneshot_pause);
@@ -62,9 +63,17 @@ function got_content() {
 fetchPreview = function(extra_action) {
 	var content = $('textarea#content').val();
 	var mongo_id = $('#mongo_id').val();
+	// Get wiki language from selected form value on create
+	var wiki_language = $('#wiki_language input:radio:checked').val();
+	if (!wiki_language) {
+		// Get wiki language from the hidden input for edits
+		wiki_language = $('input#wiki_language').val();
+	}
+	
 	var data = { 
 			 content: content,
 			 mongo_id: mongo_id,
+			 wiki_language: wiki_language,
 			 extra_action: extra_action
 		   };
 	// Don't submit ajax request if we have trivial content
@@ -79,6 +88,7 @@ fetchPreview = function(extra_action) {
 		success : function(response, status) {
 			$('#view_area').html(response.rendered_content);
 			prettyPrint();
+			sh_highlightDocument();
 	    },
 		error : function(XMLHttpRequest, textStatus, errorThrown) {
 			alert("Error: " + textStatus + " thrown: " + errorThrown); 
@@ -94,10 +104,14 @@ fetchPreview = function(extra_action) {
 function resizeEditArea() {
 	// Check that we have an edit_area first.
 	if ( $('#edit_area').length ) {
-		mojito.edit_area_fraction = 0.46;
-		mojito.edit_width = Math.floor( $(window).width() * mojito.edit_area_fraction);
-		//console.log('resizing edit area to: ' + mojito.edit_width);
+		mojito.edit_area_width_fraction = 0.46;
+		mojito.edit_width = Math.floor( $(window).width() * mojito.edit_area_width_fraction);
+		mojito.edit_area_height_fraction = 0.80;
+		mojito.edit_height = Math.floor( $(window).height() * mojito.edit_area_height_fraction);
+		//console.log('resizing edit area width to: ' + mojito.edit_width);
+		//console.log('resizing edit area height to: ' + mojito.edit_height);
 		$('textarea#content').css('width', mojito.edit_width + 'px');
+		$('textarea#content').css('height', mojito.edit_height + 'px');
 	}
 }
 
