@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Template::Role::Javascript;
 BEGIN {
-  $Mojito::Template::Role::Javascript::VERSION = '0.08';
+  $Mojito::Template::Role::Javascript::VERSION = '0.09';
 }
 use Moo::Role;
 use Mojito::Types;
@@ -20,8 +20,18 @@ sub _build_javascripts {
        [
           'jquery/jquery_min.js',
           'javascript/render_page.js',
+          'javascript/style.js',
           'syntax_highlight/prettify.js',
           'jquery/autoresize_min.js',
+          'jquery/jquery-ui-1.8.11.custom.min.js',
+          'SHJS/sh_main.min.js',
+          'SHJS/sh_perl.min.js',
+          'SHJS/sh_javascript.min.js',
+          'SHJS/sh_html.min.js',
+          'SHJS/sh_css.min.js',
+          'SHJS/sh_sql.min.js',
+          'SHJS/sh_sh.min.js',
+          'SHJS/sh_diff.min.js',
        ];
 }
 
